@@ -33,7 +33,6 @@
 #include <klineedit.h>
 #include <klocalizedstring.h>
 
-
 IMEditWidget::IMEditWidget( QWidget *parent )
   : QWidget( parent )
 {
@@ -46,6 +45,8 @@ IMEditWidget::IMEditWidget( QWidget *parent )
   mEditButton = new QToolButton;
   mEditButton->setText( i18n( "..." ) );
   layout->addWidget( mEditButton );
+  setFocusProxy( mEditButton );
+  setFocusPolicy( Qt::StrongFocus );
 
   connect( mEditButton, SIGNAL(clicked()), SLOT(edit()) );
 }
