@@ -81,8 +81,22 @@ void testFetch_data() {
 
   KIMAP::FetchJob::FetchScope scope;
   scope.mode = KIMAP::FetchJob::FetchScope::Flags;
+  scope.changedSince = 123456789;
 
   QList<QByteArray> scenario;
+  scenario << FakeServer::preauth()
+           << "C: A000001 FETCH 1:4 (FLAGS UID) (CHANGEDSINCE 123456789)"
+           << "S: * 1 FETCH ( FLAGS () UID 1 )"
+           << "S: * 2 FETCH ( FLAGS () UID 2 )"
+           << "S: * 3 FETCH ( FLAGS () UID 3 )"
+           << "S: * 4 FETCH ( FLAGS () UID 4 )"
+           << "S: A000001 OK fetch done";
+
+  QTest::newRow( "messages have empty flags (with changedsince)" ) << false << KIMAP::ImapSet( 1, 4 ) << 4
+                                               << scenario << scope;
+
+  scenario.clear();
+  scope.changedSince = 0;
   scenario << FakeServer::preauth()
            << "C: A000001 FETCH 1:4 (FLAGS UID)"
            << "S: * 1 FETCH ( FLAGS () UID 1 )"
@@ -125,6 +139,17 @@ void testFetch_data() {
            << "X";
   scope.mode = KIMAP::FetchJob::FetchScope::Headers;
   QTest::newRow( "buffer overwrite 2" ) << false << KIMAP::ImapSet( 11, 11 ) << 1 << scenario << scope;
+
+  scenario.clear();
+  scenario << FakeServer::preauth()
+           << "C: A000001 FETCH 11 (RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER] FLAGS UID) (CHANGEDSINCE 123456789)"
+           << "S: * 11 FETCH (UID 123 RFC822.SIZE 770 INTERNALDATE \"11-Oct-2010 03:33:50 +0100\" BODY[HEADER] {245}"
+           << "S: From: John Smith <jonathanr.smith@foobarbaz.com>\r\nTo: \"amagicemailaddress@foobarbazbarfoo.com\"\r\n\t<amagicemailaddress@foobarbazbarfoo.com>\r\nDate: Mon, 11 Oct 2010 03:34:48 +0100\r\nSubject: unsubscribe\r\nMessage-ID: <ASDFFDSASDFFDS@foobarbaz.com>\r\n\r\n  FLAGS ())"
+           << "S: A000001 OK fetch done";
+  scope.mode = KIMAP::FetchJob::FetchScope::FullHeaders;
+  scope.changedSince = 123456789;
+  QTest::newRow( "fetch full headers" ) << false << KIMAP::ImapSet( 11, 11 ) << 1
+                                        << scenario << scope;
 }
 
 void testFetch()
